==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetRouteSpecHttp2Route.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property actions
 * @property matches
 * @property retryPolicies
 * @property timeouts
 */
public data class GetRouteSpecHttp2Route(
    public val actions: List<GetRouteSpecHttp2RouteAction>,
    public val matches: List<GetRouteSpecHttp2RouteMatch>,
    public val retryPolicies: List<GetRouteSpecHttp2RouteRetryPolicy>,
    public val timeouts: List<GetRouteSpecHttp2RouteTimeout>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetRouteSpecHttp2Route):
            GetRouteSpecHttp2Route = GetRouteSpecHttp2Route(
            actions = javaType.actions().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttp2RouteAction.Companion.toKotlin(args0)
                })
            }),
            matches = javaType.matches().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttp2RouteMatch.Companion.toKotlin(args0)
                })
            }),
            retryPolicies = javaType.retryPolicies().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttp2RouteRetryPolicy.Companion.toKotlin(args0)
                })
            }),
            timeouts = javaType.timeouts().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttp2RouteTimeout.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetRouteSpecHttp2Route.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property actions
 * @property matches
 * @property retryPolicies
 * @property timeouts
 */
public data class GetRouteSpecHttp2Route(
    public val actions: List<GetRouteSpecHttp2RouteAction>,
    public val matches: List<GetRouteSpecHttp2RouteMatch>,
    public val retryPolicies: List<GetRouteSpecHttp2RouteRetryPolicy>,
    public val timeouts: List<GetRouteSpecHttp2RouteTimeout>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetRouteSpecHttp2Route): GetRouteSpecHttp2Route = GetRouteSpecHttp2Route(
            actions = javaType.actions().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttp2RouteAction.Companion.toKotlin(args0)
                })
            }),
            matches = javaType.matches().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttp2RouteMatch.Companion.toKotlin(args0)
                })
            }),
            retryPolicies = javaType.retryPolicies().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttp2RouteRetryPolicy.Companion.toKotlin(args0)
                })
            }),
            timeouts = javaType.timeouts().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetRouteSpecHttp2RouteTimeout.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
